%define groupid 65006
%define userid 65006

%define pkgver %(echo %version | sed 's|.P|-P|' | sed 's|.W|-W|')
%define majver %(echo %version | cut -d. -f 1-3)
%define MAJver %(echo %version | cut -d. -f 1-2)

Name:          bind
Version:       9.18.14
Release:       1mamba
Summary:       A DNS (Domain Name System) server
Group:         System/Servers
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.isc.org/bind/
Source0:       https://ftp.isc.org/isc/bind9/%{pkgver}/bind-%{pkgver}.tar.xz
Source1:       dhcp-dynamic-dns-examples.tar.bz2
Source2:       named.service
Source3:       named.logrotate
Source4:       named.sysconfig
Source5:       keygen.c
Source6:       new_key.pl
Source8:       update_bind.pl
Source10:      bind-chroot.sh
Source11:      ftp://ftp.rs.internic.net/domain/named.root
Source12:      bind-named.conf
Source13:      bind-localhost.zone
Source14:      bind-named.local
Source15:      bind-rndc.conf
Source16:      named-tmpfilesdir.conf
Patch:         %{name}-9.3.4-mktemp.patch
License:       BSD
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libcap-devel
BuildRequires: libe2fs-devel
BuildRequires: libedit-devel
BuildRequires: libjemalloc-devel
BuildRequires: libjson-c-devel
BuildRequires: libkrb5-devel
BuildRequires: liblmdb-devel
BuildRequires: libmaxminddb-devel
BuildRequires: libnghttp2-devel
BuildRequires: libopenssl-devel
BuildRequires: libtermcap-devel
BuildRequires: libuv-devel
BuildRequires: libxml2-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
%if "%{stage1}" != "1"
BuildRequires: openjade
BuildRequires: jadetex
%endif
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      %{name}-utils = %{?epoch:%epoch:}%{version}-%{release}

%description
BIND (Berkeley Internet Name Domain) is an implementation of the DNS (Domain Name System) protocols.
BIND includes a DNS server (named), which resolves host names to IP addresses; a resolver library (routines for applications to use when interfacing with DNS); and tools for verifying that the DNS server is operating properly.

%package -n lib%{name}
Summary:       Shared libraries provided by bind
Group:         Development/Libraries

%description -n lib%{name}
The libbind package contains the shared libraries provided by BIND.


%package -n lib%{name}-devel
Summary:       Include files and libraries needed for bind DNS development
Group:         Development/Libraries
Provides:      bind-devel
Obsoletes:     bind-devel < 9.18.0
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n lib%{name}-devel
The bind-devel package contains all the include files and the library required for DNS (Domain Name System) development for BIND versions 9.x.x.

%package utils
Summary:       Utilities for querying DNS name servers.
Group:         Applications/Networking
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description utils
Bind-utils contains a collection of utilities for querying DNS (Domain Name System) name servers to find out information about Internet hosts.
These tools will provide you with the IP addresses for given host names, as well as other information about registered domains and network addresses.
You should install bind-utils if you need to get information from DNS name servers.

%debug_package

%prep
%setup -q -n %{name}-%{pkgver}
#-D -T
#:<< _EOF
#%patch -p1 -b .mktemp

#pushd contrib/queryperf
#autoconf
#popd

tar xjf %{S:1}

# Fix detection of jsoncpp
#sed -i "s|/include/json/json.h|/include/json/json.h.no|" configure

%build
#:<< _EOF
%configure \
   --enable-threads \
   --enable-ipv6 \
   LIBS="-ltermcap" \
   PYTHON=%{__python3} \
%ifarch arm
   CFLAGS="%{optflags} -march=armv7-a" \
%endif
%if "%{_host}" != "%{_build}"
   --enable-epoll \
   --with-python \
   --with-randomdev=/dev/random \
   BUILD_CC=%{_build}-gcc \
%endif

%make -j1

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
mkdir -p %{buildroot}/etc/logrotate.d
mkdir -p %{buildroot}/etc/sysconfig
mkdir -p %{buildroot}%{_var}/named
#mkdir -p %{buildroot}%{_var}/run/named
mkdir -p %{buildroot}%{_var}/named/slave

install -D -m0644 %{SOURCE16} %{buildroot}%{_tmpfilesdir}/named.conf

%makeinstall

touch %{buildroot}%{_sysconfdir}/rndc.key
#cp contrib/scripts/named-bootconf.sh \
#   %{buildroot}%{_sbindir}/named-bootconf
cp contrib/scripts/nanny.pl %{buildroot}%{_sbindir}
#cp contrib/queryperf/queryperf %{buildroot}%{_sbindir}
#cp contrib/queryperf/README ./README.queryperf

install -D -m0644 %{S:2} %{buildroot}%{_unitdir}/named.service

cp %{S:3} %{buildroot}%{_sysconfdir}/logrotate.d/named
cp %{S:4} %{buildroot}/etc/sysconfig/named

%{__cc} %{optflags} -o %{buildroot}%{_sbindir}/dns-keygen %{S:5}

cp %{S:6} %{buildroot}%{_sbindir}
cp %{S:8} %{buildroot}%{_sbindir}
cp %{S:10} %{buildroot}%{_sbindir}

install -m 644 %{S:11} %{buildroot}%{_var}/named/named.ca

cp %{S:12} %{buildroot}/etc/named.conf
cp %{S:13} %{buildroot}%{_var}/named/localhost.zone
cp %{S:14} %{buildroot}%{_var}/named/named.local
cp %{S:15} %{buildroot}%{_sysconfdir}/rndc.conf

# FIXME: workaround for test files installed in build path since 9.17.2
rm -rf %{buildroot}/usr/src %{buildroot}/var/autodist

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"


%pre
if [ $1 -eq 1 ]; then
# new install
   groupadd named -g %{groupid} 2>/dev/null
   useradd -u %{userid} -c 'nameserver daemon' -d /dev/null \
      -g named -s /bin/false named
fi
exit 0

%post
if [ $1 -eq 1 ]; then
# new install
    rndckey=`dns-keygen`
    cat > /etc/rndc.key << _EOF
key "rndckey" {
    algorithm	hmac-md5;
    secret "$rndckey";
};
_EOF
fi

%tmpfiles_create named.conf

%systemd_post named
if [ $1 -ge 1 ]; then
   # clean old sysv broken links
   find /etc/rc[0-6].d/ -type l -xtype l -exec rm -f {} \;
   systemctl -q daemon-reload
   systemctl -q enable named
fi
exit 0

%preun
%systemd_preun named
exit 0

%postun
%systemd_postun_with_restart named
exit 0

%post -n lib%{name} -p /sbin/ldconfig
%postun -n lib%{name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_sysconfdir}/bind.keys
%config(noreplace) %{_sysconfdir}/sysconfig/named
%config(noreplace) %{_sysconfdir}/logrotate.d/named
%config(noreplace) %{_sysconfdir}/rndc.conf
%config(noreplace) %{_sysconfdir}/rndc.key
%config(noreplace) %{_sysconfdir}/named.conf
%attr(0755,root,root) %{_sbindir}/bind-chroot.sh
%{_bindir}/dnssec-cds
#%{_bindir}/dnssec-checkds
#%{_bindir}/dnssec-coverage
%{_bindir}/dnssec-dsfromkey
%{_bindir}/dnssec-keyfromlabel
%{_bindir}/dnssec-keygen
%{_bindir}/dnssec-importkey
%{_bindir}/dnssec-revoke
%{_bindir}/dnssec-settime
%{_bindir}/dnssec-signzone
%{_bindir}/dnssec-verify
#%{_sbindir}/lwresd
%{_sbindir}/dns-keygen
#%{_sbindir}/ddns-confgen
%{_sbindir}/named
%{_bindir}/named-rrchecker
#%attr(0755,root,root) %{_sbindir}/named-bootconf
%{_bindir}/named-checkconf
%{_bindir}/named-checkzone
%{_bindir}/named-compilezone
%{_bindir}/named-journalprint
%{_bindir}/named-nzd2nzf
%attr(0755,root,root) %{_sbindir}/nanny.pl
%attr(0755,root,root) %{_sbindir}/new_key.pl
%{_sbindir}/ddns-confgen
%{_sbindir}/rndc
%{_sbindir}/rndc-confgen
%{_sbindir}/tsig-keygen
%attr(0755,root,root) %{_sbindir}/update_bind.pl
%{_unitdir}/named.service
%{_tmpfilesdir}/named.conf
%dir %attr(0755,named,named) %{_localstatedir}/named
%attr(0755,named,named) %{_var}/named/*
%{_mandir}/man1/dnssec-cds.1*
%{_mandir}/man1/dnssec-dsfromkey.1*
%{_mandir}/man1/dnssec-keyfromlabel.1*
%{_mandir}/man1/dnssec-importkey.1*
%{_mandir}/man1/dnssec-signzone.1*
%{_mandir}/man1/dnssec-keygen.1*
%{_mandir}/man1/dnssec-revoke.1*
%{_mandir}/man1/dnssec-settime.1*
%{_mandir}/man1/dnssec-verify.1*
%{_mandir}/man1/named-checkconf.1*
%{_mandir}/man1/named-checkzone.1*
%{_mandir}/man1/named-journalprint.1*
%{_mandir}/man1/named-nzd2nzf.1*
%{_mandir}/man5/named.conf.*
%{_mandir}/man5/rndc.conf.*
%{_mandir}/man8/ddns-confgen.8*
%{_mandir}/man8/filter-a*.8*
%{_mandir}/man8/named.8*
%{_mandir}/man8/rndc-confgen.8*
%{_mandir}/man8/rndc.8*
%{_mandir}/man8/tsig-keygen.8*

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libbind9-%{version}.so
%{_libdir}/libdns-%{version}.so
%{_libdir}/libirs-%{version}.so
%{_libdir}/libisc-%{version}.so
%{_libdir}/libisccc-%{version}.so
%{_libdir}/libisccfg-%{version}.so
%{_libdir}/libns-%{version}.so
%dir %{_libdir}/bind
%{_libdir}/bind/filter-a*.so

%files -n lib%{name}-devel
%defattr(-,root,root)
#%{_bindir}/bind9-config
%dir %{_includedir}/dns/
%{_includedir}/dns/*
%dir %{_includedir}/irs/
%{_includedir}/irs/*
%dir %{_includedir}/isc/
%{_includedir}/isc/*
%dir %{_includedir}/isccc/
%{_includedir}/isccc/*
%dir %{_includedir}/isccfg/
%{_includedir}/isccfg/*
#%dir %{_includedir}/lwres/
#%{_includedir}/lwres/*
%dir %{_includedir}/dst/
%{_includedir}/dst/*
%dir %{_includedir}/bind9/
%{_includedir}/bind9/*
#%dir %{_includedir}/pk11/
#%{_includedir}/pk11/*
#%dir %{_includedir}/pkcs11/
#%{_includedir}/pkcs11/*
%dir %{_includedir}/ns/
%{_includedir}/ns/*
%{_libdir}/libbind9.so
%{_libdir}/libdns.so
%{_libdir}/libirs.so
%{_libdir}/libisc.so
%{_libdir}/libisccc.so
%{_libdir}/libisccfg.so
%{_libdir}/libns.so

%files utils
%defattr(-,root,root)
%{_bindir}/arpaname
%{_bindir}/delv
%{_bindir}/dig
%{_bindir}/mdig
%{_bindir}/host
#%{_bindir}/isc-config.sh
%{_bindir}/nslookup
%{_bindir}/nsupdate
#%{_bindir}/dnssec-keymgr
#%{_sbindir}/genrandom
#%{_sbindir}/isc-hmac-fixup
%{_bindir}/nsec3hash
%{_mandir}/man1/*
#%{_mandir}/man8/genrandom.*
#%{_mandir}/man8/isc-hmac-fixup.*
%{_mandir}/man1/nsec3hash.1*
#%{_mandir}/man1/dnssec-keymgr.1*

%changelog
* Wed Apr 19 2023 Automatic Build System <autodist@mambasoft.it> 9.18.14-1mamba
- automatic version update by autodist

* Wed Mar 15 2023 Automatic Build System <autodist@mambasoft.it> 9.18.13-1mamba
- automatic version update by autodist

* Thu Feb 16 2023 Automatic Build System <autodist@mambasoft.it> 9.18.12-1mamba
- automatic version update by autodist

* Wed Jan 25 2023 Automatic Build System <autodist@mambasoft.it> 9.18.11-1mamba
- automatic version update by autodist

* Wed Dec 21 2022 Automatic Build System <autodist@mambasoft.it> 9.18.10-1mamba
- automatic version update by autodist

* Thu Nov 17 2022 Automatic Build System <autodist@mambasoft.it> 9.18.9-1mamba
- automatic version update by autodist

* Thu Oct 20 2022 Automatic Build System <autodist@mambasoft.it> 9.18.8-1mamba
- automatic version update by autodist

* Sat Sep 24 2022 Automatic Build System <autodist@mambasoft.it> 9.18.7-1mamba
- automatic version update by autodist

* Thu Aug 18 2022 Automatic Build System <autodist@mambasoft.it> 9.18.6-1mamba
- automatic version update by autodist

* Thu Jul 21 2022 Automatic Build System <autodist@mambasoft.it> 9.18.5-1mamba
- automatic version update by autodist

* Thu Jun 16 2022 Automatic Build System <autodist@mambasoft.it> 9.18.4-1mamba
- automatic version update by autodist

* Thu May 19 2022 Automatic Build System <autodist@mambasoft.it> 9.18.3-1mamba
- automatic version update by autodist

* Thu Apr 21 2022 Automatic Build System <autodist@mambasoft.it> 9.18.2-1mamba
- automatic version update by autodist

* Wed Mar 16 2022 Automatic Build System <autodist@mambasoft.it> 9.18.1-1mamba
- automatic version update by autodist

* Thu Jan 27 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 9.18.0-1mamba
- update to 9.18.0

* Sat Jan 23 2021 Automatic Build System <autodist@mambasoft.it> 9.17.9-1mamba
- automatic version update by autodist

* Fri Jan 01 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 9.17.8-2mamba
- removed requirements for python-ply and pyhon-argparse

* Thu Dec 17 2020 Automatic Build System <autodist@mambasoft.it> 9.17.8-1mamba
- automatic version update by autodist

* Thu Nov 26 2020 Automatic Build System <autodist@mambasoft.it> 9.17.7-1mamba
- automatic version update by autodist

* Thu Oct 22 2020 Automatic Build System <autodist@mambasoft.it> 9.17.6-1mamba
- automatic version update by autodist

* Thu Sep 17 2020 Automatic Build System <autodist@mambasoft.it> 9.17.5-1mamba
- automatic version update by autodist

* Sat Aug 22 2020 Automatic Build System <autodist@mambasoft.it> 9.17.4-1mamba
- automatic version update by autodist

* Sun Jul 19 2020 Automatic Build System <autodist@mambasoft.it> 9.17.3-1mamba
- automatic version update by autodist

* Mon Jul 06 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.17.2-2mamba
- remove old examples from default named.conf

* Sat Jul 04 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.17.2-1mamba
- update to 9.17.2

* Fri Apr 17 2020 Automatic Build System <autodist@mambasoft.it> 9.17.1-1mamba
- automatic version update by autodist

* Sun Mar 29 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.17.0-2mamba
- move libraries to new libbind package

* Wed Mar 18 2020 Automatic Build System <autodist@mambasoft.it> 9.17.0-1mamba
- automatic version update by autodist

* Thu Feb 20 2020 Automatic Build System <autodist@mambasoft.it> 9.16.0-1mamba
- automatic version update by autodist

* Wed Jan 22 2020 Automatic Build System <autodist@mambasoft.it> 9.15.8-1mamba
- automatic version update by autodist

* Thu Jan 16 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.15.7-1mamba
- update to 9.15.7

* Thu Nov 21 2019 Automatic Build System <autodist@mambasoft.it> 9.15.6-1mamba
- automatic version update by autodist

* Thu Oct 17 2019 Automatic Build System <autodist@mambasoft.it> 9.15.5-1mamba
- automatic version update by autodist

* Thu Sep 19 2019 Automatic Build System <autodist@mambasoft.it> 9.15.4-1mamba
- automatic version update by autodist

* Wed Aug 28 2019 Automatic Build System <autodist@mambasoft.it> 9.15.3-1mamba
- automatic version update by autodist

* Fri Aug 16 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 9.15.2-2mamba
- add named.conf in tmpfilesdir to create /run/named

* Thu Jul 18 2019 Automatic Build System <autodist@mambasoft.it> 9.15.2-1mamba
- automatic version update by autodist

* Thu Jun 20 2019 Automatic Build System <autodist@mambasoft.it> 9.15.1-1mamba
- automatic version update by autodist

* Thu May 16 2019 Automatic Build System <autodist@mambasoft.it> 9.15.0-1mamba
- automatic version update by autodist

* Thu Apr 25 2019 Automatic Build System <autodist@mambasoft.it> 9.14.1-1mamba
- automatic version update by autodist

* Fri Mar 22 2019 Automatic Build System <autodist@mambasoft.it> 9.14.0-1mamba
- automatic version update by autodist

* Fri Feb 22 2019 Automatic Build System <autodist@mambasoft.it> 9.13.7-1mamba
- automatic version update by autodist

* Fri Feb 08 2019 Automatic Build System <autodist@mambasoft.it> 9.13.6-1mamba
- automatic version update by autodist

* Wed Dec 19 2018 Automatic Build System <autodist@mambasoft.it> 9.13.5-1mamba
- automatic version update by autodist

* Sat Sep 22 2018 Automatic Build System <autodist@mambasoft.it> 9.13.3-1mamba
- automatic version update by autodist

* Wed Jul 11 2018 Automatic Build System <autodist@mambasoft.it> 9.13.2-1mamba
- automatic version update by autodist

* Sun Jun 17 2018 Automatic Build System <autodist@mambasoft.it> 9.13.1-1mamba
- automatic version update by autodist

* Sat May 19 2018 Automatic Build System <autodist@mambasoft.it> 9.12.1.P2-1mamba
- automatic version update by autodist

* Wed Mar 14 2018 Automatic Build System <autodist@mambasoft.it> 9.12.1-1mamba
- automatic version update by autodist

* Wed Feb 07 2018 Automatic Build System <autodist@mambasoft.it> 9.12.0-1mamba
- automatic version update by autodist

* Wed Jan 17 2018 Automatic Build System <autodist@mambasoft.it> 9.11.2.P1-1mamba
- automatic version update by autodist

* Sun Jul 30 2017 Automatic Build System <autodist@mambasoft.it> 9.11.2-1mamba
- automatic version update by autodist

* Sat Jul 08 2017 Automatic Build System <autodist@mambasoft.it> 9.11.1.P3-1mamba
- automatic version update by autodist

* Tue Jul 04 2017 Automatic Build System <autodist@mambasoft.it> 9.11.1.P2-1mamba
- automatic version update by autodist

* Thu Jun 15 2017 Automatic Build System <autodist@mambasoft.it> 9.11.1.P1-1mamba
- automatic version update by autodist

* Tue Apr 25 2017 Automatic Build System <autodist@mambasoft.it> 9.11.1-1mamba
- automatic version update by autodist

* Thu Feb 09 2017 Automatic Build System <autodist@mambasoft.it> 9.11.0.P3-1mamba
- automatic version update by autodist

* Thu Jan 12 2017 Automatic Build System <autodist@mambasoft.it> 9.11.0.P2-1mamba
- automatic version update by autodist

* Wed Nov 02 2016 Automatic Build System <autodist@mambasoft.it> 9.11.0.P1-1mamba
- automatic version update by autodist

* Wed Oct 05 2016 Automatic Build System <autodist@mambasoft.it> 9.11.0-1mamba
- automatic version update by autodist

* Wed Sep 28 2016 Automatic Build System <autodist@mambasoft.it> 9.10.4.P3-1mamba
- automatic version update by autodist

* Tue Jul 19 2016 Automatic Build System <autodist@mambasoft.it> 9.10.4.P2-1mamba
- automatic version update by autodist

* Thu May 26 2016 Automatic Build System <autodist@mambasoft.it> 9.10.4.P1-1mamba
- automatic version update by autodist

* Sat Apr 30 2016 Automatic Build System <autodist@mambasoft.it> 9.10.4-1mamba
- automatic version update by autodist

* Thu Mar 10 2016 Automatic Build System <autodist@mambasoft.it> 9.10.3.P4-1mamba
- automatic version update by autodist

* Wed Jan 20 2016 Automatic Build System <autodist@mambasoft.it> 9.10.3.P3-1mamba
- automatic version update by autodist

* Wed Dec 16 2015 Automatic Build System <autodist@mambasoft.it> 9.10.3.P2-1mamba
- automatic version update by autodist

* Wed Sep 16 2015 Automatic Build System <autodist@mambasoft.it> 9.10.3-1mamba
- automatic version update by autodist

* Thu Sep 03 2015 Automatic Build System <autodist@mambasoft.it> 9.10.2.P4-1mamba
- automatic version update by autodist

* Wed Jul 29 2015 Automatic Build System <autodist@mambasoft.it> 9.10.2.P3-1mamba
- automatic version update by autodist

* Sat Jul 18 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 9.10.2.P2-2mamba
- systemd support

* Tue Jul 07 2015 Automatic Build System <autodist@mambasoft.it> 9.10.2.P2-1mamba
- automatic version update by autodist

* Thu Jun 11 2015 Automatic Build System <autodist@mambasoft.it> 9.10.2.P1-1mamba
- automatic version update by autodist

* Tue Mar 31 2015 Automatic Build System <autodist@mambasoft.it> 9.10.2-1mamba
- automatic version update by autodist

* Mon Dec 08 2014 Automatic Build System <autodist@mambasoft.it> 9.10.1.P1-1mamba
- automatic version update by autodist

* Tue Sep 23 2014 Automatic Build System <autodist@mambasoft.it> 9.10.1-1mamba
- automatic version update by autodist

* Thu Jun 12 2014 Automatic Build System <autodist@mambasoft.it> 9.10.0.P2-1mamba
- automatic version update by autodist

* Sun May 18 2014 Automatic Build System <autodist@mambasoft.it> 9.10.0.P1-1mamba
- automatic version update by autodist

* Sun Apr 13 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 9.9.5.W1-1mamba
- update to 9.9.5.W1

* Sat Feb 01 2014 Automatic Build System <autodist@mambasoft.it> 9.9.5-1mamba
- automatic version update by autodist

* Tue Jan 14 2014 Automatic Build System <autodist@mambasoft.it> 9.9.4.P2-1mamba
- automatic version update by autodist

* Thu Nov 07 2013 Automatic Build System <autodist@mambasoft.it> 9.9.4.P1-1mamba
- automatic version update by autodist

* Fri Sep 20 2013 Automatic Build System <autodist@mambasoft.it> 9.9.4-1mamba
- automatic version update by autodist

* Sat Jul 27 2013 Automatic Build System <autodist@mambasoft.it> 9.9.3.P2-1mamba
- automatic version update by autodist

* Wed Jun 05 2013 Automatic Build System <autodist@mambasoft.it> 9.9.3.P1-1mamba
- automatic version update by autodist

* Wed May 29 2013 Automatic Build System <autodist@mambasoft.it> 9.9.3-1mamba
- automatic version update by autodist

* Tue Mar 26 2013 Automatic Build System <autodist@mambasoft.it> 9.9.2.P2-1mamba
- automatic version update by autodist

* Tue Dec 04 2012 Automatic Build System <autodist@mambasoft.it> 9.9.2.P1-1mamba
- automatic version update by autodist

* Wed Oct 10 2012 Automatic Build System <autodist@mambasoft.it> 9.9.2-1mamba
- automatic version update by autodist

* Sun Aug 12 2012 Automatic Build System <autodist@mambasoft.it> 9.9.1.P2-1mamba
- automatic version update by autodist

* Mon Jun 04 2012 Automatic Build System <autodist@mambasoft.it> 9.9.1.P1-1mamba
- automatic version update by autodist

* Tue May 22 2012 Automatic Build System <autodist@mambasoft.it> 9.9.1-1mamba
- automatic version update by autodist

* Mon Apr 02 2012 Automatic Build System <autodist@mambasoft.it> 9.9.0-1mamba
- automatic version update by autodist

* Fri Dec 09 2011 Automatic Build System <autodist@mambasoft.it> 9.8.1.P1-1mamba
- update to 9.8.1.P1

* Thu Sep 01 2011 Automatic Build System <autodist@mambasoft.it> 9.8.1-1mamba
- update to 9.8.1

* Sun Jul 24 2011 Automatic Build System <autodist@mambasoft.it> 9.8.0.P4-1mamba
- update to 9.8.0.P4

* Fri Feb 18 2011 Automatic Build System <autodist@mambasoft.it> 9.7.3-1mamba
- update to 9.7.3

* Thu Dec 09 2010 Automatic Build System <autodist@mambasoft.it> 9.7.2.P3-1mamba
- automatic update by autodist

* Wed Nov 10 2010 Automatic Build System <autodist@mambasoft.it> 9.7.2.P2-1mamba
- automatic update by autodist

* Fri Sep 17 2010 Automatic Build System <autodist@mambasoft.it> 9.7.2.P1-1mamba
- automatic update to 9.7.2.P1 by autodist

* Mon Sep 13 2010 Automatic Build System <autodist@mambasoft.it> 9.7.2-1mamba
- automatic update to 9.7.2 by autodist

* Mon Aug 16 2010 Automatic Build System <autodist@mambasoft.it> 9.7.1.P2-1mamba
- automatic update by autodist

* Fri Jul 09 2010 Automatic Build System <autodist@mambasoft.it> 9.7.1.P1-1mamba
- automatic update to 9.7.1.P1 by autodist

* Sun Jun 20 2010 Automatic Build System <autodist@mambasoft.it> 9.7.1-1mamba
- automatic update to 9.7.1 by autodist

* Tue Mar 16 2010 Automatic Build System <autodist@mambasoft.it> 9.7.0.P1-1mamba
- automatic update to 9.7.0.P1 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 9.7.0-1mamba
- automatic update to 9.7.0 by autodist

* Sun Nov 29 2009 Automatic Build System <autodist@mambasoft.it> 9.6.1.P2-1mamba
- automatic update by autodist

* Wed Jul 29 2009 Automatic Build System <autodist@mambasoft.it> 9.6.1.P1-1mamba
- automatic update to 9.6.1.P1 by autodist

* Sat Jun 13 2009 Automatic Build System <autodist@mambasoft.it> 9.6.1-1mamba
- automatic update to 9.6.1 by autodist

* Thu Jan 08 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 9.6.0.P1-1mamba
- automatic update to 9.6.0.P1 by autodist

* Sun Dec 28 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 9.6.0-1mamba
- update to 9.6.0

* Sat Aug 30 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 9.5.0.P2-1mamba
- update to 9.5.0.P2

* Tue Jun 03 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 9.5.0-1mamba
- update to 9.5.0

* Tue Jun 05 2007 Aleph0 <aleph0@openmamba.org> 9.3.4-1mamba
- update to 9.3.4
- fixes the security issues CVE-2007-0493 and CVE-2007-0494
- updated initscript and patch1

* Mon Sep 11 2006 Davide Madrisan <davide.madrisan@qilinux.it> 9.3.2-2qilnx
- security update: CVE-2006-4095, CVE-2006-4096 (bugzilla#172)

* Wed Apr 12 2006 Davide Madrisan <davide.madrisan@qilinux.it> 9.3.2-1qilnx
- update to version 9.3.2 by autospec
- parallel building disabled

* Tue Nov 08 2005 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 9.3.1-1qilnx
- update to version 9.3.1 by autospec
- also fixes CAN-2005-034 (QiLinux bug#67)

* Mon Nov 29 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 9.3.0-1qilnx
- new version build
- removed automatic service activation on startup 
- added check on upgrade restart script

* Mon Aug 16 2004 Silvan Calarco <silvan.calarco@mambasoft.it> 9.2.3-3qilnx
- lame-servers logging disabled by default in named.conf

* Thu Dec 04 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 9.2.3-2qilnx
- added /var/named/slave dir

* Thu Nov 06 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 9.2.3-1qilnx
- new version rebuild

* Thu Aug 07 2003 Silvan Calarco <silvan.calarco@qinet.it> 9.2.2-7qilnx
- added automatic generation and configuration of rndc key
- update %%post etc. scripts to new-style

* Fri Jun 06 2003 Silvan Calarco <silvan.calarco@qinet.it> 9.2.2-6qilnx
- fixed /var/named dir ownership

* Wed May 21 2003 Silvan Calarco <silvan.calarco@qinet.it> 9.2.2-5qilnx
- added bind-utils require
- moved user creation in pre script

* Tue May 20 2003 Silvan Calarco <silvan.calarco@qinet.it> 9.2.2-4qilnx
- modified initscript so that service is started ok when effectively available

* Mon May 19 2003 Silvan Calarco <silvan.calarco@qinet.it> 9.2.2-3qilnx
- fixed configuration errors

* Wed May 14 2003 Alessandro Ramazzina <alessandro.ramazzina@qinet.it> 9.2.2-2qilnx
- Added attributes to the initrd files

* Mon May 12 2003 Alessandro Ramazzina <alessandro.ramazzina@qinet.it> 9.2.2-1qilnx
- creation of bind package
